BarType

Enum BarType 

#[repr(C)]
pub enum BarType { Standard { instrument_id: InstrumentId, spec: BarSpecification, aggregation_source: AggregationSource, }, Composite { instrument_id: InstrumentId, spec: BarSpecification, aggregation_source: AggregationSource, composite_step: usize, composite_aggregation: BarAggregation, composite_aggregation_source: AggregationSource, }, }
Represents a bar type including the instrument ID, bar specification and aggregation source.

Variants



Standard

Fields

instrument_id: InstrumentId

The bar type’s instrument ID.

spec: BarSpecification

The bar type’s specification.

aggregation_source: AggregationSource

The bar type’s aggregation source.



Composite

Fields

instrument_id: InstrumentId

The bar type’s instrument ID.

spec: BarSpecification

The bar type’s specification.

aggregation_source: AggregationSource

The bar type’s aggregation source.

composite_step: usize

The composite step for binning samples for bar aggregation.

composite_aggregation: BarAggregation

The composite type of bar aggregation.

composite_aggregation_source: AggregationSource

The composite bar type’s aggregation source.

Implementations

Source

impl BarType

pub fn new( instrument_id: InstrumentId, spec: BarSpecification, aggregation_source: AggregationSource, ) -> Self

Creates a new BarType instance.

pub fn new_composite( instrument_id: InstrumentId, spec: BarSpecification, aggregation_source: AggregationSource, composite_step: usize, composite_aggregation: BarAggregation, composite_aggregation_source: AggregationSource, ) -> Self

Creates a new composite BarType instance.

pub fn is_standard(&self) -> bool

Returns whether this instance is a standard bar type.

pub fn is_composite(&self) -> bool

Returns whether this instance is a composite bar type.

pub fn is_externally_aggregated(&self) -> bool

Returns whether the bar aggregation source is EXTERNAL.

pub fn is_internally_aggregated(&self) -> bool

Returns whether the bar aggregation source is INTERNAL.

pub fn standard(&self) -> Self

Returns the standard bar type component.

pub fn composite(&self) -> Self

Returns any composite bar type component.

pub fn instrument_id(&self) -> InstrumentId

Returns the InstrumentId for this bar type.

pub fn spec(&self) -> BarSpecification

Returns the BarSpecification for this bar type.

pub fn aggregation_source(&self) -> AggregationSource

Returns the AggregationSource for this bar type.

pub fn id_spec_key(&self) -> (InstrumentId, BarSpecification)

Returns the instrument ID and bar specification as a tuple key.

Useful as a hashmap key when aggregation source should be ignored, such as for indicator registration where INTERNAL and EXTERNAL bars should trigger the same indicators.