OrderBookDelta

Struct OrderBookDelta 

#[repr(C)]
pub struct OrderBookDelta { pub instrument_id: InstrumentId, pub action: BookAction, pub order: BookOrder, pub flags: u8, pub sequence: u64, pub ts_event: UnixNanos, pub ts_init: UnixNanos, }
Represents a single change/delta in an order book.

Fields

instrument_id: InstrumentId

The instrument ID for the book.

action: BookAction

The order book delta action.

order: BookOrder

The order to apply.

flags: u8

The record flags bit field indicating event end and data information.

sequence: u64

The message sequence number assigned at the venue.

ts_event: UnixNanos

UNIX timestamp (nanoseconds) when the book event occurred.

ts_init: UnixNanos

UNIX timestamp (nanoseconds) when the instance was created.

Implementations

Source

impl OrderBookDelta

pub fn new_checked( instrument_id: InstrumentId, action: BookAction, order: BookOrder, flags: u8, sequence: u64, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Result<Self>

Creates a new OrderBookDelta instance with correctness checking.

Errors

Returns an error if action is BookAction::Add or BookAction::Update and size is not positive (> 0).

Notes

PyO3 requires a Result type for proper error handling and stacktrace printing in Python.

pub fn new( instrument_id: InstrumentId, action: BookAction, order: BookOrder, flags: u8, sequence: u64, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self

Creates a new OrderBookDelta instance.

Panics

Panics if action is BookAction::Add or BookAction::Update and size is not positive (> 0).

pub fn clear( instrument_id: InstrumentId, sequence: u64, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self

Creates a new OrderBookDelta instance with a Clear action and NULL order.

pub fn get_metadata( instrument_id: &InstrumentId, price_precision: u8, size_precision: u8, ) -> HashMap<String, String>

Returns the metadata for the type, for use with serialization formats.

pub fn get_fields() -> IndexMap<String, String>

Returns the field map for the type, for use with Arrow schemas.