MarkPriceUpdate

Struct MarkPriceUpdate 

#[repr(C)]
pub struct MarkPriceUpdate { pub instrument_id: InstrumentId, pub value: Price, pub ts_event: UnixNanos, pub ts_init: UnixNanos, }
Represents a mark price update.

Fields

instrument_id: InstrumentId

The instrument ID for the mark price.

value: Price

The mark price.

ts_event: UnixNanos

UNIX timestamp (nanoseconds) when the price event occurred.

ts_init: UnixNanos

UNIX timestamp (nanoseconds) when the instance was created.

Implementations

Source

impl MarkPriceUpdate

pub fn new( instrument_id: InstrumentId, value: Price, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self

Creates a new MarkPriceUpdate instance.

pub fn get_metadata( instrument_id: &InstrumentId, price_precision: u8, ) -> HashMap<String, String>

Returns the metadata for the type, for use with serialization formats.

pub fn get_fields() -> IndexMap<String, String>

Returns the field map for the type, for use with Arrow schemas.