#[repr(C)]pub struct InstrumentStatus {
pub instrument_id: InstrumentId,
pub action: MarketStatusAction,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
pub reason: Option<Ustr>,
pub trading_event: Option<Ustr>,
pub is_trading: Option<bool>,
pub is_quoting: Option<bool>,
pub is_short_sell_restricted: Option<bool>,
}Expand description
Represents an event that indicates a change in an instrument market status.
Fields
instrument_id: InstrumentIdThe instrument ID for the status change.
action: MarketStatusActionThe instrument market status action.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the status event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the instance was created.
reason: Option<Ustr>Additional details about the cause of the status change.
trading_event: Option<Ustr>Further information about the status change (if provided).
is_trading: Option<bool>The state of trading in the instrument.
is_quoting: Option<bool>The state of quoting in the instrument.
is_short_sell_restricted: Option<bool>The state of short sell restrictions for the instrument (if applicable).
Implementations
Sourceimpl InstrumentStatus
impl InstrumentStatus
Sourcepub fn new(
instrument_id: InstrumentId,
action: MarketStatusAction,
ts_event: UnixNanos,
ts_init: UnixNanos,
reason: Option<Ustr>,
trading_event: Option<Ustr>,
is_trading: Option<bool>,
is_quoting: Option<bool>,
is_short_sell_restricted: Option<bool>,
) -> Self
pub fn new( instrument_id: InstrumentId, action: MarketStatusAction, ts_event: UnixNanos, ts_init: UnixNanos, reason: Option<Ustr>, trading_event: Option<Ustr>, is_trading: Option<bool>, is_quoting: Option<bool>, is_short_sell_restricted: Option<bool>, ) -> Self
Creates a new InstrumentStatus instance.
Sourcepub fn get_metadata(instrument_id: &InstrumentId) -> HashMap<String, String>
pub fn get_metadata(instrument_id: &InstrumentId) -> HashMap<String, String>
Returns the metadata for the type, for use with serialization formats.