pub struct StubCustomData {
pub ts_init: UnixNanos,
pub value: i64,
}Expand description
Stub custom data type for integration tests (e.g. Redis cache).
Fields
ts_init: UnixNanosvalue: i64Trait Implementations
Sourceimpl Clone for StubCustomData
impl Clone for StubCustomData
Sourcefn clone(&self) -> StubCustomData
fn clone(&self) -> StubCustomData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomDataTrait for StubCustomData
impl CustomDataTrait for StubCustomData
Sourcefn clone_arc(&self) -> Arc<dyn CustomDataTrait>
fn clone_arc(&self) -> Arc<dyn CustomDataTrait>
Returns a cloned Arc of the custom data.
Sourcefn eq_arc(&self, other: &dyn CustomDataTrait) -> bool
fn eq_arc(&self, other: &dyn CustomDataTrait) -> bool
Returns whether the custom data is equal to another.
Sourcefn type_name_static() -> &'static str
fn type_name_static() -> &'static str
Returns the type name used in serialized form (e.g. in the
"type" field).Sourcefn from_json(value: Value) -> Result<Arc<dyn CustomDataTrait>>
fn from_json(value: Value) -> Result<Arc<dyn CustomDataTrait>>
Deserializes from a JSON value into an Arc’d trait object. Read more
Sourceimpl Debug for StubCustomData
impl Debug for StubCustomData
Sourceimpl<'de> Deserialize<'de> for StubCustomData
impl<'de> Deserialize<'de> for StubCustomData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl HasTsInit for StubCustomData
impl HasTsInit for StubCustomData
Sourceimpl PartialEq for StubCustomData
impl PartialEq for StubCustomData
Sourceimpl Serialize for StubCustomData
impl Serialize for StubCustomData
impl StructuralPartialEq for StubCustomData