#[repr(C)]pub enum PositionSideSpecified {
Flat = 1,
Long = 2,
Short = 3,
}Expand description
The market side for a specific position, or action related to positions.
Variants
Flat = 1
A neural/flat position, where no position is currently held in the market.
Long = 2
A long position in the market, typically acquired through one or many BUY orders.
Short = 3
A short position in the market, typically acquired through one or many SELL orders.
Implementations
Sourceimpl PositionSideSpecified
impl PositionSideSpecified
Sourcepub fn as_position_side(&self) -> PositionSide
pub fn as_position_side(&self) -> PositionSide
Converts this specified side into a PositionSide.