#[repr(C)]pub enum TimeInForce {
Gtc = 1,
Ioc = 2,
Fok = 3,
Gtd = 4,
Day = 5,
AtTheOpen = 6,
AtTheClose = 7,
}Expand description
The ‘Time in Force’ instruction for an order.
Variants
Gtc = 1
Good Till Cancel (GTC) - Remains active until canceled.
Ioc = 2
Immediate or Cancel (IOC) - Executes immediately to the extent possible, with any unfilled portion canceled.
Fok = 3
Fill or Kill (FOK) - Executes in its entirety immediately or is canceled if full execution is not possible.
Gtd = 4
Good Till Date (GTD) - Remains active until the specified expiration date or time is reached.
Day = 5
Day - Remains active until the close of the current trading session.
AtTheOpen = 6
At the Opening (ATO) - Executes at the market opening or expires if not filled.
AtTheClose = 7
At the Closing (ATC) - Executes at the market close or expires if not filled.
Implementations
Sourceimpl TimeInForce
impl TimeInForce