pub struct ComponentId(/* private fields */);Expand description
Represents a valid component ID.
Implementations
Sourceimpl ComponentId
impl ComponentId
Sourcepub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
pub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
Creates a new ComponentId instance with correctness checking.
Errors
Returns an error if value is not a valid string.
Notes
PyO3 requires a Result type for proper error handling and stacktrace printing in Python.