pub struct ExecAlgorithmId(/* private fields */);Expand description
Represents a valid execution algorithm ID.
Implementations
Sourceimpl ExecAlgorithmId
impl ExecAlgorithmId
Sourcepub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
pub fn new_checked<T: AsRef<str>>(value: T) -> CorrectnessResult<Self>
Creates a new ExecAlgorithmId instance with correctness checking.
Errors
Returns an error if value is not a valid string.
Notes
PyO3 requires a Result type for proper error handling and stacktrace printing in Python.