#[repr(C)]pub struct Commodity {Show 22 fields
pub id: InstrumentId,
pub raw_symbol: Symbol,
pub asset_class: AssetClass,
pub quote_currency: Currency,
pub price_precision: u8,
pub size_precision: u8,
pub price_increment: Price,
pub size_increment: Quantity,
pub margin_init: Decimal,
pub margin_maint: Decimal,
pub maker_fee: Decimal,
pub taker_fee: Decimal,
pub lot_size: Option<Quantity>,
pub max_quantity: Option<Quantity>,
pub min_quantity: Option<Quantity>,
pub max_notional: Option<Money>,
pub min_notional: Option<Money>,
pub max_price: Option<Price>,
pub min_price: Option<Price>,
pub info: Option<Params>,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents a generic commodity instrument.
Fields
id: InstrumentIdThe instrument ID.
raw_symbol: SymbolThe raw/local/native symbol for the instrument, assigned by the venue.
asset_class: AssetClassThe asset class of the commodity.
quote_currency: CurrencyThe quote currency.
price_precision: u8The price decimal precision.
size_precision: u8The trading size decimal precision.
price_increment: PriceThe minimum price increment (tick size).
size_increment: QuantityThe minimum size increment.
margin_init: DecimalThe initial (order) margin requirement in percentage of order value.
margin_maint: DecimalThe maintenance (position) margin in percentage of position value.
maker_fee: DecimalThe fee rate for liquidity makers as a percentage of order value.
taker_fee: DecimalThe fee rate for liquidity takers as a percentage of order value.
lot_size: Option<Quantity>The rounded lot unit size (standard/board).
max_quantity: Option<Quantity>The maximum allowable order quantity.
min_quantity: Option<Quantity>The minimum allowable order quantity.
max_notional: Option<Money>The maximum allowable order notional value.
min_notional: Option<Money>The minimum allowable order notional value.
max_price: Option<Price>The maximum allowable quoted price.
min_price: Option<Price>The minimum allowable quoted price.
info: Option<Params>Additional instrument metadata as a JSON-serializable dictionary.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the data event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the data object was initialized.
Implementations
Sourceimpl Commodity
impl Commodity
Sourcepub fn new_checked(
instrument_id: InstrumentId,
raw_symbol: Symbol,
asset_class: AssetClass,
quote_currency: Currency,
price_precision: u8,
size_precision: u8,
price_increment: Price,
size_increment: Quantity,
lot_size: Option<Quantity>,
max_quantity: Option<Quantity>,
min_quantity: Option<Quantity>,
max_notional: Option<Money>,
min_notional: Option<Money>,
max_price: Option<Price>,
min_price: Option<Price>,
margin_init: Option<Decimal>,
margin_maint: Option<Decimal>,
maker_fee: Option<Decimal>,
taker_fee: Option<Decimal>,
info: Option<Params>,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> CorrectnessResult<Self>
pub fn new_checked( instrument_id: InstrumentId, raw_symbol: Symbol, asset_class: AssetClass, quote_currency: Currency, price_precision: u8, size_precision: u8, price_increment: Price, size_increment: Quantity, lot_size: Option<Quantity>, max_quantity: Option<Quantity>, min_quantity: Option<Quantity>, max_notional: Option<Money>, min_notional: Option<Money>, max_price: Option<Price>, min_price: Option<Price>, margin_init: Option<Decimal>, margin_maint: Option<Decimal>, maker_fee: Option<Decimal>, taker_fee: Option<Decimal>, info: Option<Params>, ts_event: UnixNanos, ts_init: UnixNanos, ) -> CorrectnessResult<Self>
Sourcepub fn new(
instrument_id: InstrumentId,
raw_symbol: Symbol,
asset_class: AssetClass,
quote_currency: Currency,
price_precision: u8,
size_precision: u8,
price_increment: Price,
size_increment: Quantity,
lot_size: Option<Quantity>,
max_quantity: Option<Quantity>,
min_quantity: Option<Quantity>,
max_notional: Option<Money>,
min_notional: Option<Money>,
max_price: Option<Price>,
min_price: Option<Price>,
margin_init: Option<Decimal>,
margin_maint: Option<Decimal>,
maker_fee: Option<Decimal>,
taker_fee: Option<Decimal>,
info: Option<Params>,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub fn new( instrument_id: InstrumentId, raw_symbol: Symbol, asset_class: AssetClass, quote_currency: Currency, price_precision: u8, size_precision: u8, price_increment: Price, size_increment: Quantity, lot_size: Option<Quantity>, max_quantity: Option<Quantity>, min_quantity: Option<Quantity>, max_notional: Option<Money>, min_notional: Option<Money>, max_price: Option<Price>, min_price: Option<Price>, margin_init: Option<Decimal>, margin_maint: Option<Decimal>, maker_fee: Option<Decimal>, taker_fee: Option<Decimal>, info: Option<Params>, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self