EnumIterator

Struct EnumIterator 

pub struct EnumIterator { /* private fields */ }
Python iterator over the variants of an enum.

Implementations

Source

impl EnumIterator

pub fn new<'py, E>(py: Python<'py>) -> Self

Creates a new Python iterator over the variants of an enum.

Panics

Panics if conversion of enum variants into Python objects fails.