pub fn pyobjects_to_option_greeks(
data: Vec<Bound<'_, PyAny>>,
) -> PyResult<Vec<OptionGreeks>>Expand description
Transforms the given Python objects into a vector of OptionGreeks objects.
Errors
Returns a PyErr if element conversion fails or the data is not monotonically increasing.