FillReport

Struct FillReport 

pub struct FillReport {
Show 15 fields pub account_id: AccountId, pub instrument_id: InstrumentId, pub venue_order_id: VenueOrderId, pub trade_id: TradeId, pub order_side: OrderSide, pub last_qty: Quantity, pub last_px: Price, pub commission: Money, pub liquidity_side: LiquiditySide, pub avg_px: Option<Decimal>, pub report_id: UUID4, pub ts_event: UnixNanos, pub ts_init: UnixNanos, pub client_order_id: Option<ClientOrderId>, pub venue_position_id: Option<PositionId>,
}
Represents a fill report of a single order execution.

Fields

account_id: AccountId

The account ID associated with the position.

instrument_id: InstrumentId

The instrument ID associated with the event.

venue_order_id: VenueOrderId

The venue assigned order ID.

trade_id: TradeId

The trade match ID (assigned by the venue).

order_side: OrderSide

The order side.

last_qty: Quantity

The last fill quantity for the position.

last_px: Price

The last fill price for the position.

commission: Money

The commission generated from the fill.

liquidity_side: LiquiditySide

The liquidity side of the execution.

avg_px: Option<Decimal>

The cumulative or chunk average execution price when provided by the venue.

report_id: UUID4

The unique identifier for the event.

ts_event: UnixNanos

UNIX timestamp (nanoseconds) when the event occurred.

ts_init: UnixNanos

UNIX timestamp (nanoseconds) when the event was initialized.

client_order_id: Option<ClientOrderId>

The client order ID.

venue_position_id: Option<PositionId>

The position ID (assigned by the venue).

Implementations

Source

impl FillReport

pub fn new( account_id: AccountId, instrument_id: InstrumentId, venue_order_id: VenueOrderId, trade_id: TradeId, order_side: OrderSide, last_qty: Quantity, last_px: Price, commission: Money, liquidity_side: LiquiditySide, client_order_id: Option<ClientOrderId>, venue_position_id: Option<PositionId>, ts_event: UnixNanos, ts_init: UnixNanos, report_id: Option<UUID4>, ) -> Self

Creates a new FillReport instance with required fields.

pub const fn has_client_order_id(&self) -> bool

Checks if the fill has a client order ID.

pub const fn has_venue_position_id(&self) -> bool

Utility method to check if the fill has a venue position ID.