#[repr(C)]pub struct Bar {
pub bar_type: BarType,
pub open: Price,
pub high: Price,
pub low: Price,
pub close: Price,
pub volume: Quantity,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents an aggregated bar.
Fields
bar_type: BarTypeThe bar type for this bar.
open: PriceThe bars open price.
high: PriceThe bars high price.
low: PriceThe bars low price.
close: PriceThe bars close price.
volume: QuantityThe bars volume.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the data event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the instance was created.
Implementations
Sourceimpl Bar
impl Bar
Sourcepub fn new_checked(
bar_type: BarType,
open: Price,
high: Price,
low: Price,
close: Price,
volume: Quantity,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Result<Self>
pub fn new_checked( bar_type: BarType, open: Price, high: Price, low: Price, close: Price, volume: Quantity, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Result<Self>
Sourcepub fn new(
bar_type: BarType,
open: Price,
high: Price,
low: Price,
close: Price,
volume: Quantity,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub fn new( bar_type: BarType, open: Price, high: Price, low: Price, close: Price, volume: Quantity, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self
pub fn instrument_id(&self) -> InstrumentId
Sourcepub fn get_metadata(
bar_type: &BarType,
price_precision: u8,
size_precision: u8,
) -> HashMap<String, String>
pub fn get_metadata( bar_type: &BarType, price_precision: u8, size_precision: u8, ) -> HashMap<String, String>
Returns the metadata for the type, for use with serialization formats.
Sourcepub fn get_fields() -> IndexMap<String, String>
pub fn get_fields() -> IndexMap<String, String>
Returns the field map for the type, for use with Arrow schemas.