#[repr(C)]pub struct BarSpecification {
pub step: NonZeroUsize,
pub aggregation: BarAggregation,
pub price_type: PriceType,
}Expand description
Represents a bar aggregation specification including a step, aggregation method/rule and price type.
Fields
step: NonZeroUsizeThe step for binning samples for bar aggregation.
aggregation: BarAggregationThe type of bar aggregation.
price_type: PriceTypeThe price type to use for aggregation.
Implementations
Sourceimpl BarSpecification
impl BarSpecification
Sourcepub fn new_checked(
step: usize,
aggregation: BarAggregation,
price_type: PriceType,
) -> Result<Self>
pub fn new_checked( step: usize, aggregation: BarAggregation, price_type: PriceType, ) -> Result<Self>
Creates a new BarSpecification instance with correctness checking.
Errors
Returns an error if step is not positive (> 0), or if step is not
valid for a fixed-subunit time aggregation.
Notes
PyO3 requires a Result type for proper error handling and stacktrace printing in Python.
Sourcepub fn new(
step: usize,
aggregation: BarAggregation,
price_type: PriceType,
) -> Self
pub fn new( step: usize, aggregation: BarAggregation, price_type: PriceType, ) -> Self
Creates a new BarSpecification instance.
Panics
Panics if step is not positive (> 0), or if step is not valid for
a fixed-subunit time aggregation.
Sourcepub fn timedelta(&self) -> TimeDelta
pub fn timedelta(&self) -> TimeDelta
Returns the TimeDelta interval for this bar specification.
Notes
For BarAggregation::Month and BarAggregation::Year, proxy values are used
(30 days for months, 365 days for years) to estimate their respective durations,
since months and years have variable lengths.
Panics
Panics if the aggregation method is not time-based, or if step is too
large for the interval arithmetic.
Sourcepub fn is_time_aggregated(&self) -> bool
pub fn is_time_aggregated(&self) -> bool
Return a value indicating whether the aggregation method is time-driven:
Sourcepub fn is_threshold_aggregated(&self) -> bool
pub fn is_threshold_aggregated(&self) -> bool
Return a value indicating whether the aggregation method is threshold-driven:
Sourcepub fn is_information_aggregated(&self) -> bool
pub fn is_information_aggregated(&self) -> bool
Return a value indicating whether the aggregation method is information-driven: