#[repr(C)]pub struct InstrumentClose {
pub instrument_id: InstrumentId,
pub close_price: Price,
pub close_type: InstrumentCloseType,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents an instrument close at a venue.
Fields
instrument_id: InstrumentIdThe instrument ID.
close_price: PriceThe closing price for the instrument.
close_type: InstrumentCloseTypeThe type of closing price.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the close price event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the instance was created.
Implementations
Sourceimpl InstrumentClose
impl InstrumentClose
Sourcepub fn new(
instrument_id: InstrumentId,
close_price: Price,
close_type: InstrumentCloseType,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub fn new( instrument_id: InstrumentId, close_price: Price, close_type: InstrumentCloseType, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self
Creates a new InstrumentClose instance.
Sourcepub fn get_metadata(
instrument_id: &InstrumentId,
price_precision: u8,
) -> HashMap<String, String>
pub fn get_metadata( instrument_id: &InstrumentId, price_precision: u8, ) -> HashMap<String, String>
Returns the metadata for the type, for use with serialization formats.
Sourcepub fn get_fields() -> IndexMap<String, String>
pub fn get_fields() -> IndexMap<String, String>
Returns the field map for the type, for use with Arrow schemas.
Sourceimpl InstrumentClose
impl InstrumentClose
pub fn py_close_price(&self) -> Price
pub fn py_close_type(&self) -> InstrumentCloseType
pub fn py_ts_event(&self) -> u64
pub fn py_ts_init(&self) -> u64
Sourceimpl InstrumentClose
impl InstrumentClose
Sourcepub fn from_pyobject(obj: &Bound<'_, PyAny>) -> PyResult<Self>
pub fn from_pyobject(obj: &Bound<'_, PyAny>) -> PyResult<Self>
Creates a new InstrumentClose from a Python object reference.
Errors
Returns a PyErr if retrieving any attribute or converting types fails.