#[repr(C)]pub struct OrderBookDelta {
pub instrument_id: InstrumentId,
pub action: BookAction,
pub order: BookOrder,
pub flags: u8,
pub sequence: u64,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents a single change/delta in an order book.
Fields
instrument_id: InstrumentIdThe instrument ID for the book.
action: BookActionThe order book delta action.
order: BookOrderThe order to apply.
flags: u8The record flags bit field indicating event end and data information.
sequence: u64The message sequence number assigned at the venue.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the book event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the instance was created.
Implementations
Sourceimpl OrderBookDelta
impl OrderBookDelta
Sourcepub fn new_checked(
instrument_id: InstrumentId,
action: BookAction,
order: BookOrder,
flags: u8,
sequence: u64,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Result<Self>
pub fn new_checked( instrument_id: InstrumentId, action: BookAction, order: BookOrder, flags: u8, sequence: u64, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Result<Self>
Creates a new OrderBookDelta instance with correctness checking.
Errors
Returns an error if action is BookAction::Add or BookAction::Update and size is not positive (> 0).
Notes
PyO3 requires a Result type for proper error handling and stacktrace printing in Python.
Sourcepub fn new(
instrument_id: InstrumentId,
action: BookAction,
order: BookOrder,
flags: u8,
sequence: u64,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub fn new( instrument_id: InstrumentId, action: BookAction, order: BookOrder, flags: u8, sequence: u64, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self
Creates a new OrderBookDelta instance.
Panics
Panics if action is BookAction::Add or BookAction::Update and size is not positive (> 0).
Sourcepub fn clear(
instrument_id: InstrumentId,
sequence: u64,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub fn clear( instrument_id: InstrumentId, sequence: u64, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self
Creates a new OrderBookDelta instance with a Clear action and NULL order.
Sourcepub fn get_metadata(
instrument_id: &InstrumentId,
price_precision: u8,
size_precision: u8,
) -> HashMap<String, String>
pub fn get_metadata( instrument_id: &InstrumentId, price_precision: u8, size_precision: u8, ) -> HashMap<String, String>
Returns the metadata for the type, for use with serialization formats.
Sourcepub fn get_fields() -> IndexMap<String, String>
pub fn get_fields() -> IndexMap<String, String>
Returns the field map for the type, for use with Arrow schemas.