#[repr(C)]pub struct MarkPriceUpdate {
pub instrument_id: InstrumentId,
pub value: Price,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents a mark price update.
Fields
instrument_id: InstrumentIdThe instrument ID for the mark price.
value: PriceThe mark price.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the price event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the instance was created.
Implementations
Sourceimpl MarkPriceUpdate
impl MarkPriceUpdate
Sourcepub fn new(
instrument_id: InstrumentId,
value: Price,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub fn new( instrument_id: InstrumentId, value: Price, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self
Creates a new MarkPriceUpdate instance.
Sourcepub fn get_metadata(
instrument_id: &InstrumentId,
price_precision: u8,
) -> HashMap<String, String>
pub fn get_metadata( instrument_id: &InstrumentId, price_precision: u8, ) -> HashMap<String, String>
Returns the metadata for the type, for use with serialization formats.
Sourcepub fn get_fields() -> IndexMap<String, String>
pub fn get_fields() -> IndexMap<String, String>
Returns the field map for the type, for use with Arrow schemas.
Sourceimpl MarkPriceUpdate
impl MarkPriceUpdate
Sourcepub fn from_pyobject(obj: &Bound<'_, PyAny>) -> PyResult<Self>
pub fn from_pyobject(obj: &Bound<'_, PyAny>) -> PyResult<Self>
Creates a new MarkPriceUpdate from a Python object.
Errors
Returns a PyErr if attribute extraction or type conversion fails.