#[repr(C)]pub enum OrderType {
Market = 1,
Limit = 2,
StopMarket = 3,
StopLimit = 4,
MarketToLimit = 5,
MarketIfTouched = 6,
LimitIfTouched = 7,
TrailingStopMarket = 8,
TrailingStopLimit = 9,
}Expand description
The type of order.
Variants
Market = 1
A market order to buy or sell at the best available price in the current market.
Limit = 2
A limit order to buy or sell at a specific price or better.
StopMarket = 3
A stop market order to buy or sell once the price reaches the specified stop/trigger price. When the stop price is reached, the order effectively becomes a market order.
StopLimit = 4
A stop limit order to buy or sell which combines the features of a stop order and a limit order. Once the stop/trigger price is reached, a stop-limit order effectively becomes a limit order.
MarketToLimit = 5
A market-to-limit order is a market order that is to be executed as a limit order at the current best market price after reaching the market.
MarketIfTouched = 6
A market-if-touched order effectively becomes a market order when the specified trigger price is reached.
LimitIfTouched = 7
A limit-if-touched order effectively becomes a limit order when the specified trigger price is reached.
TrailingStopMarket = 8
A trailing stop market order sets the stop/trigger price at a fixed “trailing offset” amount from the market.
TrailingStopLimit = 9
A trailing stop limit order combines the features of a trailing stop order with those of a limit order.
Implementations