#[repr(C)]pub enum TriggerType {
NoTrigger = 0,
Default = 1,
LastPrice = 2,
MarkPrice = 3,
IndexPrice = 4,
BidAsk = 5,
DoubleLast = 6,
DoubleBidAsk = 7,
LastOrBidAsk = 8,
MidPoint = 9,
}Expand description
The trigger type for the stop/trigger price of an order.
Variants
NoTrigger = 0
No trigger type is specified (invalid for orders with a trigger).
Default = 1
The default trigger type set by the trading venue.
LastPrice = 2
Based on the last traded price for the instrument.
MarkPrice = 3
Based on the mark price for the instrument.
IndexPrice = 4
Based on the index price for the instrument.
BidAsk = 5
Based on the top-of-book quoted prices for the instrument.
DoubleLast = 6
Based on a ‘double match’ of the last traded price for the instrument
DoubleBidAsk = 7
Based on a ‘double match’ of the bid/ask price for the instrument
LastOrBidAsk = 8
Based on both the TriggerType::LastPrice and TriggerType::BidAsk.
MidPoint = 9
Based on the mid-point of the TriggerType::BidAsk.
Implementations
Sourceimpl TriggerType
impl TriggerType