pub struct PositionStatusReport {
pub account_id: AccountId,
pub instrument_id: InstrumentId,
pub position_side: PositionSideSpecified,
pub quantity: Quantity,
pub signed_decimal_qty: Decimal,
pub report_id: UUID4,
pub ts_last: UnixNanos,
pub ts_init: UnixNanos,
pub venue_position_id: Option<PositionId>,
pub avg_px_open: Option<Decimal>,
}Expand description
Represents a position status at a point in time.
Fields
account_id: AccountIdThe account ID associated with the position.
instrument_id: InstrumentIdThe instrument ID associated with the event.
position_side: PositionSideSpecifiedThe position side.
quantity: QuantityThe current open quantity.
signed_decimal_qty: DecimalThe current signed quantity as a decimal (positive for position side LONG, negative for SHORT).
report_id: UUID4The unique identifier for the event.
ts_last: UnixNanosUNIX timestamp (nanoseconds) when the last event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the event was initialized.
venue_position_id: Option<PositionId>The position ID (assigned by the venue).
avg_px_open: Option<Decimal>The reported average open price for the position.
Implementations
Sourceimpl PositionStatusReport
impl PositionStatusReport
Sourcepub fn new(
account_id: AccountId,
instrument_id: InstrumentId,
position_side: PositionSideSpecified,
quantity: Quantity,
ts_last: UnixNanos,
ts_init: UnixNanos,
report_id: Option<UUID4>,
venue_position_id: Option<PositionId>,
avg_px_open: Option<Decimal>,
) -> Self
pub fn new( account_id: AccountId, instrument_id: InstrumentId, position_side: PositionSideSpecified, quantity: Quantity, ts_last: UnixNanos, ts_init: UnixNanos, report_id: Option<UUID4>, venue_position_id: Option<PositionId>, avg_px_open: Option<Decimal>, ) -> Self
Creates a new PositionStatusReport instance with required fields.
Sourcepub const fn has_venue_position_id(&self) -> bool
pub const fn has_venue_position_id(&self) -> bool
Checks if the position has a venue position ID.